<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function pgc_sgb_frontend_scripts(){
	$slug = 'pgc-simply-gallery-block';
	$version = '1.2.0';
	
	 /** Parser */
	 wp_enqueue_script(
		$slug . '-script',
		plugins_url( '/blocks/pgc_sgb.min.js', dirname( __FILE__ ) ),
		false,
		$version,
		true
	);

	/** Skins List */
	$skinsList = array();
	$skinsSettings=array();
	$skins_folders = glob(realpath( dirname( __FILE__ ) ) . '/skins/*.js');
	foreach ( $skins_folders as $file ) {
		$fileName = substr($file,strrpos($file,"/")+1);
		$skinSlug = substr($fileName,0,-3);
		$skinsList[$skinSlug] = plugins_url( '/blocks/skins/', dirname( __FILE__ ) ).$fileName.'?ver='.$version;
		$skinsSettings[$skinSlug] = get_option($skinSlug);
		//delete_option($skinSlug);
  	}
 
	wp_localize_script( $slug.'-script', 'PGC_SGB',
			array(
				'ajaxurl'   => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce('pgc-sgb-nonce'),
				'assets' => plugins_url('/assets/',dirname( __FILE__ )),
				'skinsFolder' => plugins_url('/blocks/skins/',dirname( __FILE__ )), 
				'skinsList' => $skinsList,  /** Skins List */
				'skinsSettings' => $skinsSettings,
				'admin' => is_admin()
			)
		);
}

function simply_gallery_block_assets() {
	$slug = 'pgc-simply-gallery-block'; //Name Space
	$version = '1.1.5';

	wp_register_style(
		$slug.'-frontend', // Handle.
		plugins_url( 'dist/blocks.style.build.css', dirname( __FILE__ ) ), // Block style CSS.
		array(), // Dependency to include the CSS after it.
		$version
	);

	wp_register_script(
		$slug.'-js', // Handle.
		plugins_url( '/dist/blocks.build.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		$version,
		true // Enqueue the script in the footer.
	);
		
	register_block_type(
		'pgcsimplygalleryblock/masonry', 
		array(
			'style'         => $slug.'-frontend',
			'editor_script' => $slug.'-js',
			'editor_style'  => $slug.'-editor',
		)
	);
	register_block_type(
		'pgcsimplygalleryblock/justified', 
		array(
			'style'         => $slug.'-frontend',
			'editor_script' => $slug.'-js',
			'editor_style'  => $slug.'-editor',
		)
	);
	register_block_type(
		'pgcsimplygalleryblock/grid', 
		array(
			'style'         => $slug.'-frontend',
			'editor_script' => $slug.'-js',
			'editor_style'  => $slug.'-editor',
		)
	);
}

function update_def_settings(){
	check_ajax_referer( 'pgc-sgb-nonce', 'nonce' );
	
	$globaldata  =  stripslashes($_POST['gallSet']);
	$json = json_decode($globaldata);
	$out = array();
	if(isset($json->galleryType) && isset($json->settings)){
		$out['message']=update_option( $json->galleryType, $json->settings)?'true':'false';
	}else{
		$out['message'] = 'false';
	}
	
	header('Content-Type: application/json; charset=' . get_option('blog_charset'), true);
	echo json_encode($out);
	wp_die();
}
if( wp_doing_ajax() ){
	add_action('wp_ajax_pgc_sgb_update_def_settings', 'update_def_settings');
}

add_action( 'init', 'simply_gallery_block_assets' );
add_action( 'wp_enqueue_scripts', 'pgc_sgb_frontend_scripts' );
add_action( 'the_post', 'pgc_sgb_frontend_scripts' );
